import type { VxeGridProps } from '#/adapter/vxe-table';

import { DictEnum } from '@vben/constants';
import { getPopupContainer } from '@vben/utils';

import { type FormSchemaGetter } from '#/adapter/form';
import { getDictOptions } from '#/utils/dict';
import { renderDict } from '#/utils/render';

export const querySchema: FormSchemaGetter = () => [
  {
    component: 'Input',
    fieldName: 'equName',
    label: '设备名称'
  },
  {
    component: 'Input',
    fieldName: 'assetNo',
    label: '资产编号'
  },
  {
    component: 'Select',
    componentProps: {
      options: getDictOptions(DictEnum.EIMS_INSPECT_TYPE)
    },
    fieldName: 'inspType',
    label: '点检类型'
  },
  {
    component: 'TreeSelect',
    // 在drawer里更新 这里不需要默认的componentProps
    defaultValue: undefined,
    fieldName: 'inspDept',
    label: '点检部门',

  },
  {
    component: 'Select',
    componentProps: {
      allowClear: true,
      showSearch: true,
      getPopupContainer
    },
    fieldName: 'inspUser',
    label: '点检人',
  },
  {
    component: 'Select',
    componentProps: {
      options: getDictOptions(DictEnum.SYS_NORMAL_DISABLE)
    },
    fieldName: 'status',
    label: '状态'
  },
];

export const columns: VxeGridProps['columns'] = [
  { type: 'checkbox', width: 60, fixed: 'left' },
  {
    title: '设备名称',
    field: 'equName',
    minWidth: 200,
    fixed: 'left'
  },
  {
    title: '资产编号',
    field: 'assetNo',
    minWidth: 160
  },
  {
    title: '状态',
    field: 'status',
    minWidth: 80,
    slots: {
      default: ({ row }) => {
        return renderDict(row.status, DictEnum.SYS_NORMAL_DISABLE);
      }
    }
  },
  {
    title: '点检项',
    field: 'inspName',
    minWidth: 200
  },
  {
    title: '点检类型',
    field: 'inspType',
    minWidth: 120,
    slots: {
      default: ({ row }) => {
        return renderDict(row.inspType, DictEnum.EIMS_INSPECT_TYPE);
      }
    }
  },
  {
    title: '点检人',
    field: 'inspUserName',
    minWidth: 100
  },
  {
    title: '循环周期',
    field: 'inspCycleUnitName',
    minWidth: 80
  },
  {
    title: '时间计算规则',
    field: 'inspRule',
    minWidth: 140,
    slots: {
      default: ({ row }) => {
        return renderDict(row.inspRule, DictEnum.MAINT_TIME_RULE);
      }
    }
  },
  {
    title: '首次执行时间',
    field: 'inspFirstTime',
    minWidth: 160
  },
  {
    title: '上次执行时间',
    field: 'inspLastTime',
    minWidth: 160
  },
  {
    title: '下次执行时间',
    field: 'inspNextTime',
    minWidth: 160
  },
  {
    title: '创建时间',
    field: 'createTime',
    minWidth: 200
  },
  {
    field: 'action',
    fixed: 'right',
    slots: { default: 'action' },
    title: '操作',
    width: 200
  }
];

export const drawerSchema: FormSchemaGetter = () => [
  {
    component: 'Input',
    dependencies: {
      show: () => false,
      triggerFields: ['']
    },
    fieldName: 'id'
  },
  {
    component: 'Input',
    fieldName: 'equId',
    label: '设备id',
    dependencies: {
      show: () => false,
      triggerFields: ['']
    }
  },
  {
    component: 'Input',
    fieldName: 'equName',
    label: '设备名称'
  },
  {
    component: 'Input',
    fieldName: 'inspName',
    label: '点检项'
  },
  {
    component: 'RadioGroup',
    componentProps: {
      buttonStyle: 'solid',
      options: getDictOptions(DictEnum.EIMS_INSPECT_TYPE),
      optionType: 'button'
    },
    fieldName: 'inspType',
    defaultValue: '1',
    label: '点检类型'
  },
  {
    component: 'Input',
    fieldName: 'inspDesc',
    label: '点检说明'
  },
  {
    component: 'InputNumber',
    fieldName: 'inspCycle',
    label: '点检周期',
    formItemClass: 'col-span-1',
    componentProps: {
      min: 1
    }
  },
  {
    component: 'Select',
    componentProps: {
      getPopupContainer,
      options: getDictOptions(DictEnum.MAINT_CYCLE_UNIT)
    },
    fieldName: 'inspCycleUnit',
    formItemClass: 'col-span-1 w-[80px]',
    labelWidth: 0,
    label: ''
  },

  {
    component: 'Select',
    componentProps: {
      getPopupContainer,
      options: getDictOptions(DictEnum.MAINT_TIME_RULE)
    },
    fieldName: 'inspRule',
    label: '点检规则 '
  },
  {
    component: 'Input',
    fieldName: 'inspUser',
    label: '用户id',
    dependencies: {
      show: () => false,
      triggerFields: ['']
    }
  },
  {
    component: 'Input',
    fieldName: 'inspUserName',
    label: '点检人'
  },
  {
    component: 'Input',
    fieldName: 'inspDept',
    label: '部门id',
    dependencies: {
      show: () => false,
      triggerFields: ['']
    }
  },
  {
    component: 'RadioGroup',
    componentProps: {
      buttonStyle: 'solid',
      options: getDictOptions(DictEnum.SYS_NORMAL_DISABLE),
      optionType: 'button'
    },
    fieldName: 'status',
    defaultValue: '0',
    label: '状态'
  },
  {
    component: 'DatePicker',
    componentProps: {
      format: 'YYYY-MM-DD',
      showTime: false,
      valueFormat: 'YYYY-MM-DD',
      getPopupContainer
    },
    fieldName: 'inspFirstTime',
    label: '首次保养时间'
  },
  {
    component: 'DatePicker',
    componentProps: {
      format: 'YYYY-MM-DD',
      showTime: false,
      valueFormat: 'YYYY-MM-DD',
      getPopupContainer
    },
    fieldName: 'inspLastTime',
    label: '上次保养时间'
  },
  {
    component: 'DatePicker',
    componentProps: {
      format: 'YYYY-MM-DD',
      showTime: false,
      valueFormat: 'YYYY-MM-DD',
      getPopupContainer
    },
    fieldName: 'inspNextTime',
    label: '下次保养时间',
  },
  {
    component: 'Textarea',
    fieldName: 'remark',
    label: '备注'
  }
];
